@@ -2,6 +2,7 @@ import time
 import requests
 import os
 from functools import wraps
+import functools
 from fastapi import Request, Body
 
 from magicapi.Models.Task import Task, TaskParams
@@ -20,7 +21,12 @@ from magicapi import g
 from magicapi.Decorators.helpers import async_safe
 
 
-def run_in_background_no_dynamo(f):
+def run_in_background_no_dynamo(f=None, background_url: str = None):
+    if not f:
+        return functools.partial(
+            run_in_background_no_dynamo, background_url=background_url
+        )
+
     router_path = f"/run_in_background_no_dynamo/{f.__name__}"
     new_r = APIRouter()
 
@@ -42,7 +48,7 @@ def run_in_background_no_dynamo(f):
             params=Params(args=list(args), kwargs=kwargs), created_at=datetime.utcnow()
         )
         headers = {"Content-Type": "application/json", "Accept": "application/json"}
-        url = f"{g.base_url}{router_path}"
+        url = f"{background_url or g.base_url}{router_path}"
         try:
             requests.post(
                 url=url,
@@ -56,7 +62,9 @@ def run_in_background_no_dynamo(f):
     return wrapper
 
 
-def run_in_background(f):
+def run_in_background(f=None, background_url: str = None):
+    if not f:
+        return functools.partial(run_in_background, background_url=background_url)
     router_path = f"/run_in_background/{f.__name__}"
     new_r = APIRouter()
 
@@ -109,9 +117,11 @@ def run_in_background(f):
             print("given to function", "args", args, "kwargs", kwargs)
         task_params = TaskParams(args=list(args), kwargs=kwargs)
         now = datetime.utcnow()
+
+        base_url = background_url or g.base_url
         task = Task(
             task_id=random_str(30),
-            url=g.base_url + router_path,
+            url=base_url + router_path,
             status="queued",
             sent=False,
             secret_token=random_str(50),
